"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.filterDiffJson = filterDiffJson;
exports.filterFileBasedOnLint = filterFileBasedOnLint;
exports.filterLintReportBasedOnImpactLine = filterLintReportBasedOnImpactLine;
var _path = _interopRequireDefault(require("path"));
var _getModifiedLines = require("../getModifiedLines");
var _getFileUtils = require("./getFileUtils");
var _fileUtils = require("../../utils/fileUtils");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
/**
 * @function  filterLintReportBasedOnImpactLine -  Filter Report Based on Impact Line
 * @param {JSON} lintReport - Lint report  generated by eslint 
 * @param {Map} reportLineMap - This Map contains file as key  and impacted lines as value
 * @param {string} filePath - File path of violated code
 * @returns {JSON} 
 * 
 * @note - If they call impact based as false then filter not apply
 */

function filterLintReportBasedOnImpactLine(lintReport, reportLineMap, filePath) {
  var impactedLines = reportLineMap.get(filePath);
  var regex = /Definition for rule '(.+)' was not found\./;
  lintReport.messages = lintReport.messages.filter(function (message) {
    if (filterNotDefinedRule(message.message, regex)) {
      return false;
    }
    if (impactedLines.includes(message.line)) {
      // To set pipeline status 
      message["severity"] == 2 ? global.reportStatus = false : null;
      return true;
    }
    return false;
  });
  return lintReport;
}

/**
 * @function filterDiffJson  - Filter file path From git diff json and Create Map diff file as key  and impacted lines as value
 * @param {JSON} diffJson -  Git Diff JSON  (This JSON get by git diff api)
 * @returns {Map} 
 */

function filterDiffJson(diffJson) {
  var _diffJson$diffs;
  var diffFilesMap = new Map();
  diffJson === null || diffJson === void 0 || (_diffJson$diffs = diffJson.diffs) === null || _diffJson$diffs === void 0 || _diffJson$diffs.forEach(function (diff) {
    var diffPathKey = _path["default"].resolve((0, _getFileUtils.getRootGitPath)(), diff.new_path);
    if (diffPathKey === undefined) {
      return;
    }
    if (diffPathKey) {
      diffFilesMap.set(diffPathKey, (0, _getModifiedLines.getModifiedLines)(diff.diff).modifiedLines);
    }
  });
  return diffFilesMap;
}
function filterFileBasedOnLint(lintReport) {
  return lintReport;
}

/**
 * @function filterNotDefinedRule -  It test message with given regex
 * @param {string} message  - report message
 * @returns {Boolean}
 */
function filterNotDefinedRule(message, regex) {
  return regex.test(message);
}