"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.constructConfigPath = constructConfigPath;
exports.filterJsFiles = filterJsFiles;
exports.getFilesFromBranchDiff = getFilesFromBranchDiff;
exports.getLintReportPath = getLintReportPath;
exports.getRootGitPath = getRootGitPath;
exports.getStagedFiles_CI = getStagedFiles_CI;
exports.getStagedFiles_preCommit = getStagedFiles_preCommit;
exports.resolvePath = resolvePath;
var _path = _interopRequireDefault(require("path"));
var _child_process = require("child_process");
var _logger = require("../../utils/logger");
var _fileUtils = require("../../utils/fileUtils");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
/**
 * @function getFilesFromBranchDiff  - filter file path From git diff json 
 * @param {JSON} diffJson -  Git Diff JSON  (This JSON get by git diff api)
 * @returns {Array<String>} 
 */

function getFilesFromBranchDiff(diffJson) {
  var rootPath = getRootGitPath();
  return diffJson === null || diffJson === void 0 ? void 0 : diffJson.diffs.map(function (diff) {
    return _path["default"].resolve(rootPath, diff === null || diff === void 0 ? void 0 : diff.new_path);
  });
}

/**
 * @function getLintReportPath - construct lint report path
 * @returns {string}
 */

function getLintReportPath() {
  return _path["default"].resolve(process.cwd(), "lint-report", "lintReport.json");
}

/**
 * @function resolvePath - resolve given  file path 
 * @param {string} resolveFilePath -  file path 
 * @returns {string}
 */

function resolvePath(resolveFilePath) {
  var file_Path = _path["default"].resolve(resolveFilePath);
  if (!(0, _fileUtils.checkIfFileExists)(file_Path)) {
    _logger.Logger.log(_logger.Logger.FAILURE_TYPE, "file does not exist ..");
    process.exit(0);
  }
  return file_Path;
}
function getStagedFiles_preCommit() {
  var command = "git diff --cached -U0 HEAD --name-only";
  var child = (0, _child_process.spawnSync)(command, {
    shell: true
  });
  var diffFiles = child.stdout.toString().split("\n").map(function (filePath) {
    return _path["default"].resolve(getRootGitPath(), filePath);
  });
  diffFiles.pop(); // remove last empty string
  return diffFiles;
}

/**
 * @function getStagedFiles_CI - check Linter trigger from and Filter lint files
 * @param {JSON} branch_diff_json - Git Diff JSON  (This JSON get by git diff api)
 * @returns {Array<String>}
 */

function getStagedFiles_CI(branch_diff_json) {
  if (typeof branch_diff_json === "boolean" && !branch_diff_json) {
    _logger.Logger.log(_logger.Logger.FAILURE_TYPE, "Expected Either branch diff json or files. but received ".concat(typeof branch_diff_json === "boolean" ? "empty string" : "empty diff", " "));
    process.exit(0);
  }
  var filteredDiffFiles = getFilesFromBranchDiff(branch_diff_json);
  return filteredDiffFiles;
}

/**
 * @function getRootGitPath -  get git root path
 * @returns {string}
 */
function getRootGitPath() {
  var childProcess = (0, _child_process.spawnSync)("git", ["rev-parse", "--show-toplevel"], {
    shell: true
  });
  return childProcess.stdout.toString().split("\n").filter(Boolean).pop();
}

// /**
//  * @function getConfigurationFilePath - get lint configuration path based on cli command
//  * @returns {string}
//  */

// function getConfigurationFilePath() {
//   const configPath = constructConfigPath();
//   const eslintConfigPath = path.resolve(process.cwd(), ".eslintrc.js");
//   if (checkIfFileExists(configPath)) {
//     return configPath;
//   }
//   if (!checkIfFileExists(configPath) && !checkIfFileExists(eslintConfigPath)) {
//     Logger.log(
//       Logger.FAILURE_TYPE,
//       `configuration file or eslint configuration files is not exist`
//     );
//     process.exit(0);
//   }
//   if (checkIfFileExists(eslintConfigPath)) {
//     return eslintConfigPath;
//   }
// }

function constructConfigPath() {
  return _path["default"].resolve(process.cwd(), ".eslintrc.js");
}

/**
 * @function filterJsFiles - filter javascript files. omit feature files
 * @param {Array<String>} lintFiles - linter files as Array
 * @returns {Array<String>} 
 */

function filterJsFiles(lintFiles) {
  return lintFiles.filter(function (file) {
    if (file.includes('.feature')) {
      return false;
    }
    return true;
  });
}