"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getBranchName = getBranchName;
exports.getCredentials = getCredentials;
exports.getGitUsername = getGitUsername;
exports.getProjectName = getProjectName;
exports.getProjectNameFrmGit = getProjectNameFrmGit;
exports.getRepoName = getRepoName;
exports.getSonarHostUrl = getSonarHostUrl;
exports.getSonarProperties = getSonarProperties;
exports.getSpawnOutput = getSpawnOutput;
var _rootPath = require("../../utils/rootPath");
var _path = _interopRequireDefault(require("path"));
var _child_process = require("child_process");
var _getFileUtils = require("../eslint/getFileUtils");
var _fileUtils = require("../../utils/fileUtils");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
/**
 * @function getSonarHostUrl - get sonar host url  from property file
 * @returns {string}
 */

function getSonarHostUrl() {
  var _require = require((0, _fileUtils.getLintPropertiesFilePath)()),
    sonar_hostURL = _require.sonar_hostURL;
  return sonar_hostURL;
}

/**
 * @function getProjectName - get  project name for sonarQube project
 * @param {Object} cliArgument -  Object represent cli Argument
 * @returns {string}
 */

function getProjectName(cliArgument) {
  var date = new Date();
  var timeSuffix = "".concat(date.getUTCDate(), "_").concat(date.getHours(), "_", "UTC");
  var _cliArgument$repo = cliArgument.repo,
    repo = _cliArgument$repo === void 0 ? null : _cliArgument$repo,
    _cliArgument$branch = cliArgument.branch,
    branch = _cliArgument$branch === void 0 ? null : _cliArgument$branch,
    _cliArgument$username = cliArgument.username,
    username = _cliArgument$username === void 0 ? null : _cliArgument$username,
    _cliArgument$dir = cliArgument.dir,
    dir = _cliArgument$dir === void 0 ? null : _cliArgument$dir;
  var default_project = getProjectNameFrmGit();
  var project_name = dir ? "".concat(default_project, "_dev_").concat(timeSuffix) : repo && branch && username ? "".concat(repo, "_").concat(branch, "_").concat(username) : "".concat(default_project, "_ci");
  return project_name;
}
function getTestFiles(cliArgument) {
  return " ";
}
/**
 * @function getLintFiles_ci - filter files based on cli argument
 * @param {Object} cliArgument -  Object represent cli Argument
 * @returns {Array<string>}
 */

function getLintFiles_ci(cliArgument) {
  var _cliArgument$diffPath = cliArgument.diffPath,
    diffPath = _cliArgument$diffPath === void 0 ? false : _cliArgument$diffPath,
    _cliArgument$dir2 = cliArgument.dir,
    dir = _cliArgument$dir2 === void 0 ? false : _cliArgument$dir2;
  if (dir && !diffPath) {
    return (0, _fileUtils.getFilesPathFromRootDir)(dir);
  }
  return (0, _getFileUtils.getFilesFromBranchDiff)(require((0, _getFileUtils.resolvePath)(diffPath)));
}

/**
 * @function getSonarProperties -  collect all sonar properties
 * @param {Object} cliObjects -  Object represent cli Argument
 * @returns {Array<Object>}
 */

function getSonarProperties(cliObjects) {
  var _cliObjects$lintJsonP = cliObjects.lintJsonPath,
    lintJsonPath = _cliObjects$lintJsonP === void 0 ? null : _cliObjects$lintJsonP;
  var sonarqube_host_url = getSonarHostUrl();
  var sonar_scanner_path = (0, _rootPath.getSonarJarPath)();
  var _getCredentials = getCredentials(),
    Dlogin = _getCredentials.Dlogin,
    Dpassword = _getCredentials.Dpassword;
  var project_name = getProjectName(cliObjects);
  var resultFilesPath = getTestFiles(cliObjects);
  var source_directories = getLintFiles_ci(cliObjects);
  var command = ["-jar", sonar_scanner_path, "-Dsonar.host.url=".concat(sonarqube_host_url), "-Dsonar.projectKey=".concat(project_name), "-Dsonar.login=".concat(Dlogin), "-Dsonar.password=".concat(Dpassword), "-Dsonar.sources=".concat(source_directories), "-Dsonar.tests=".concat(resultFilesPath), "-Dsonar.language=js", "-Dsonar.working.directory=".concat(getSonarArtifactsDir()), "-Dsonar.eslint.reportPaths=".concat((0, _getFileUtils.getLintReportPath)(lintJsonPath)), "-Dsonar.javascript.lcov.reportPaths=coverage/lcov-report/lcov.info"];
  return command;
}

/**
 * @function getProjectNameFrmGit - get project from git
 * @returns {string}
 */

function getProjectNameFrmGit() {
  var $repoName = getRepoName();
  var $branchName = getBranchName();
  var $username = getGitUsername();
  return $repoName && $branchName && $username ? "".concat($repoName, "_").concat($branchName, "_").concat($username) : "desk_default_projects";
}
/**
 * @function getGitUsername - get username from git
 * @returns {string}
 */

function getGitUsername() {
  var userName = getSpawnOutput("git", ["config", "user.email"]);
  return userName.pop().split("@")[0];
}

/**
 * @function getRepoName - get repo name from git
 * @returns {string}
 */

function getRepoName() {
  var repoName = getSpawnOutput("git", ["remote", "get-url", "origin"]);
  return repoName.pop().split("/").pop().split(".")[0];
}

/**
 * @function getBranchName - get branch name from git
 * @returns {string}
 */

function getBranchName() {
  // git rev-parse --abbrev-ref HEAD
  var branchName = getSpawnOutput("git", ["rev-parse", "--abbrev-ref", "HEAD"]); // to get current branch
  return branchName.shift().trim();
}

/**
 * @function getSpawnOutput -  run execution in spawn method
 * @param {string} command - prefix command
 * @param {Array<string>} params - command 
 * @returns {string | any}
 */

function getSpawnOutput(command) {
  var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  var demon_process = (0, _child_process.spawnSync)(command, params, {
    shell: true
  });
  return demon_process.stdout.toString().split("\n").filter(Boolean);
}

/**
 * @function getCredentials -  get credentials for sonarQube
 * @returns {Object}
 */

function getCredentials() {
  var _require2 = require((0, _fileUtils.getLintPropertiesFilePath)()),
    loginName = _require2.loginName,
    password = _require2.password;
  return {
    Dlogin: loginName,
    Dpassword: password
  };
}

/**
 * @function getSonarArtifactsDir - get artifacts path for sonarQube
 * @returns {string}
 */

function getSonarArtifactsDir() {
  return _path["default"].resolve(process.cwd(), "lint-report", ".scannerwork");
}