"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.cliArgsToObject = cliArgsToObject;
exports.objectToCliArgs = objectToCliArgs;
/**
 * @function cliArgsToObject -  convert cli argument to object
 * @param {Array<string>} cliArgs - cli argument from enduser
 * @param {any} isKeyNeedToBeAdded - option
 * @returns {Object}
 */
function cliArgsToObject(cliArgs) {
  var isKeyNeedToBeAdded = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
  var processEnv = {};
  cliArgs.forEach(function (option) {
    if (/^--./.test(option)) {
      var equIndex = option.indexOf('=');
      var key = option.slice(2, equIndex);
      var value = option.slice(equIndex + 1);
      if (equIndex === -1) {
        key = option.slice(2);
        value = true;
      }
      processEnv[key] = value;
    }
  });
  return processEnv;
}

/**
 * @function cliArgsToObject -  convert object argument to cliArgs
 * @param {Object} objectToBeConverted - object need to convert
 * @param {any} isKeyNeedToBeAdded -  option
 * @returns {Array<string>}
 */

function objectToCliArgs(objectToBeConverted, isKeyNeedToBeAdded) {
  var argsArray = [];
  Object.keys(objectToBeConverted).forEach(function (key) {
    if (isKeyNeedToBeAdded(key)) {
      if (typeof objectToBeConverted[key] === 'boolean' && objectToBeConverted[key]) {
        argsArray.push("--".concat(key));
      } else {
        argsArray.push("--".concat(key, "=").concat(objectToBeConverted[key]));
      }
    }
  });
  return argsArray;
}